# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/orbit/orbit.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/orbit/orbit.proto',
  package='stellarstation.api.v1.orbit',
  syntax='proto3',
  serialized_options=b'\n\037com.stellarstation.api.v1.orbitB\nOrbitProtoP\001Z8github.com/infostellarinc/go-stellarstation/api/v1/orbit',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'stellarstation/api/v1/orbit/orbit.proto\x12\x1bstellarstation.api.v1.orbit\"%\n\x03Tle\x12\x0e\n\x06line_1\x18\x01 \x01(\t\x12\x0e\n\x06line_2\x18\x02 \x01(\tBi\n\x1f\x63om.stellarstation.api.v1.orbitB\nOrbitProtoP\x01Z8github.com/infostellarinc/go-stellarstation/api/v1/orbitb\x06proto3'
)




_TLE = _descriptor.Descriptor(
  name='Tle',
  full_name='stellarstation.api.v1.orbit.Tle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='line_1', full_name='stellarstation.api.v1.orbit.Tle.line_1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_2', full_name='stellarstation.api.v1.orbit.Tle.line_2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=109,
)

DESCRIPTOR.message_types_by_name['Tle'] = _TLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tle = _reflection.GeneratedProtocolMessageType('Tle', (_message.Message,), {
  'DESCRIPTOR' : _TLE,
  '__module__' : 'stellarstation.api.v1.orbit.orbit_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.orbit.Tle)
  })
_sym_db.RegisterMessage(Tle)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
