# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stellarstation/api/v1/monitoring/monitoring.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from stellarstation.api.v1.antenna import antenna_pb2 as stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2
from stellarstation.api.v1.common import common_pb2 as stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2
from stellarstation.api.v1.orbit import orbit_pb2 as stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2
from stellarstation.api.v1.radio import radio_pb2 as stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stellarstation/api/v1/monitoring/monitoring.proto',
  package='stellarstation.api.v1.monitoring',
  syntax='proto3',
  serialized_options=b'\n$com.stellarstation.api.v1.monitoringB\017MonitoringProtoP\001Z=github.com/infostellarinc/go-stellarstation/api/v1/monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1stellarstation/api/v1/monitoring/monitoring.proto\x12 stellarstation.api.v1.monitoring\x1a\x1egoogle/protobuf/wrappers.proto\x1a+stellarstation/api/v1/antenna/antenna.proto\x1a)stellarstation/api/v1/common/common.proto\x1a\'stellarstation/api/v1/orbit/orbit.proto\x1a\'stellarstation/api/v1/radio/radio.proto\"\xfe\x01\n\x18TransmitterConfiguration\x12;\n\nmodulation\x18\x01 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\x12\x1a\n\x12is_carrier_enabled\x18\x02 \x01(\x08\x12\x0f\n\x07\x62itrate\x18\x03 \x01(\x04\x12<\n\x0bline_coding\x18\x04 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\x12\x1b\n\x13\x66ilter_bandwidth_hz\x18\x05 \x01(\x04\x12\x1d\n\x15sampling_frequency_hz\x18\x06 \x01(\x04\"\xee\x03\n\x15ReceiverConfiguration\x12;\n\nmodulation\x18\x01 \x01(\x0e\x32\'.stellarstation.api.v1.radio.Modulation\x12\x14\n\x0c\x62\x61ndwidth_hz\x18\x02 \x01(\x04\x12\x1d\n\x15sampling_frequency_hz\x18\x03 \x01(\x04\x12\x0f\n\x07\x62itrate\x18\x04 \x01(\x04\x12<\n\x0bline_coding\x18\x05 \x01(\x0e\x32\'.stellarstation.api.v1.radio.LineCoding\x12@\n\x14synchronization_word\x18\x06 \x01(\x0b\x32\".stellarstation.api.v1.common.Bits\x12*\n\"is_convolutional_code_descrambling\x18\x07 \x01(\x08\x12&\n\x1eis_convolutional_code_decoding\x18\x08 \x01(\x08\x12&\n\x1eis_convolutional_code_inverted\x18\t \x01(\x08\x12\x1f\n\x17is_reed_solomon_enabled\x18\n \x01(\x08\x12\x12\n\nframe_size\x18\x0b \x01(\r\x12!\n\x19is_frame_checking_enabled\x18\x0c \x01(\x08\"B\n\x11PlanConfiguration\x12-\n\x03tle\x18\x01 \x01(\x0b\x32 .stellarstation.api.v1.orbit.Tle\"\xc1\x02\n\x1aGroundStationConfiguration\x12O\n\x0btransmitter\x18\x01 \x01(\x0b\x32:.stellarstation.api.v1.monitoring.TransmitterConfiguration\x12I\n\x08receiver\x18\x02 \x01(\x0b\x32\x37.stellarstation.api.v1.monitoring.ReceiverConfiguration\x12\x44\n\x07\x61ntenna\x18\x03 \x01(\x0b\x32\x33.stellarstation.api.v1.antenna.AntennaConfiguration\x12\x41\n\x04plan\x18\x04 \x01(\x0b\x32\x33.stellarstation.api.v1.monitoring.PlanConfiguration\"\x96\x03\n\x10TransmitterState\x12\x1b\n\x13\x63\x65nter_frequency_hz\x18\x01 \x01(\x04\x12\x19\n\x11\x63\x61rrier_level_dbm\x18\x02 \x01(\x01\x12\x39\n\x15is_modulation_enabled\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12is_carrier_enabled\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x37\n\x13is_if_sweep_enabled\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12;\n\x17is_idle_pattern_enabled\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x07\x62itrate\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x33\n\x0e\x63\x61rrier_offset\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\xb3\x02\n\x11ReedSolomonStatus\x12J\n\x06status\x18\x01 \x01(\x0e\x32:.stellarstation.api.v1.monitoring.ReedSolomonStatus.Status\x12\x1d\n\x15num_corrected_signals\x18\x02 \x01(\r\x12\x34\n\x0fnum_good_frames\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\x0enum_bad_frames\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"H\n\x06Status\x12\x06\n\x02OK\x10\x00\x12\x14\n\x10INTERLEAVE_ERROR\x10\x01\x12 \n\x1c\x43ORRECTION_CAPACITY_EXCEEDED\x10\x02\"\x86\x04\n\rReceiverState\x12\x1b\n\x13\x63\x65nter_frequency_hz\x18\x01 \x01(\x04\x12\x19\n\x11\x63\x61rrier_level_dbm\x18\x02 \x01(\x01\x12\x17\n\x0fis_phase_locked\x18\x03 \x01(\x08\x12\"\n\x1ais_bit_synchronizer_locked\x18\x04 \x01(\x08\x12\x16\n\x0enormalized_snr\x18\x05 \x01(\x01\x12$\n\x1cis_frame_synchronizer_locked\x18\x06 \x01(\x08\x12`\n\x1b\x63onvolutional_coding_status\x18\x07 \x01(\x0e\x32;.stellarstation.api.v1.monitoring.ConvolutionalCodingStatus\x12+\n#convolutional_coding_bit_error_rate\x18\x08 \x01(\x01\x12P\n\x13reed_solomon_status\x18\t \x01(\x0b\x32\x33.stellarstation.api.v1.monitoring.ReedSolomonStatus\x12,\n\x07\x62itrate\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValue\x12\x33\n\x0e\x63\x61rrier_offset\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.FloatValue\"\x94\x02\n\x0c\x41ntennaState\x12\x45\n\x07\x61zimuth\x18\x01 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.AntennaState.Angle\x12G\n\televation\x18\x02 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.AntennaState.Angle\x12H\n\x0cpolarization\x18\x03 \x01(\x0e\x32\x32.stellarstation.api.v1.antenna.AntennaPolarization\x1a*\n\x05\x41ngle\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\x01\x12\x10\n\x08measured\x18\x02 \x01(\x01\"\xe1\x01\n\x12GroundStationState\x12G\n\x0btransmitter\x18\x01 \x01(\x0b\x32\x32.stellarstation.api.v1.monitoring.TransmitterState\x12\x41\n\x08receiver\x18\x02 \x01(\x0b\x32/.stellarstation.api.v1.monitoring.ReceiverState\x12?\n\x07\x61ntenna\x18\x03 \x01(\x0b\x32..stellarstation.api.v1.monitoring.AntennaState\"\x97\x03\n\x12PlanLifecycleEvent\x12K\n\x06status\x18\x01 \x01(\x0e\x32;.stellarstation.api.v1.monitoring.PlanLifecycleEvent.Status\x12V\n\x07\x66\x61ilure\x18\x02 \x01(\x0b\x32\x43.stellarstation.api.v1.monitoring.PlanLifecycleEvent.FailureDetailsH\x00\x1a\x80\x01\n\x0e\x46\x61ilureDetails\x12X\n\x05\x63\x61use\x18\x01 \x01(\x0e\x32I.stellarstation.api.v1.monitoring.PlanLifecycleEvent.FailureDetails.Cause\"\x14\n\x05\x43\x61use\x12\x0b\n\x07UNKNOWN\x10\x00\"N\n\x06Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tPREPARING\x10\x01\x12\r\n\tEXECUTING\x10\x02\x12\r\n\tCOMPLETED\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\t\n\x07\x44\x65tails\"X\n\x12GroundStationEvent\x12\x42\n\x04plan\x18\x04 \x01(\x0b\x32\x34.stellarstation.api.v1.monitoring.PlanLifecycleEvent*Q\n\x19\x43onvolutionalCodingStatus\x12\x0c\n\x08UNLOCKED\x10\x00\x12\x0c\n\x08I_LOCKED\x10\x01\x12\x0c\n\x08Q_LOCKED\x10\x02\x12\n\n\x06LOCKED\x10\x03\x42x\n$com.stellarstation.api.v1.monitoringB\x0fMonitoringProtoP\x01Z=github.com/infostellarinc/go-stellarstation/api/v1/monitoringb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2.DESCRIPTOR,stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2.DESCRIPTOR,])

_CONVOLUTIONALCODINGSTATUS = _descriptor.EnumDescriptor(
  name='ConvolutionalCodingStatus',
  full_name='stellarstation.api.v1.monitoring.ConvolutionalCodingStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNLOCKED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='I_LOCKED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Q_LOCKED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCKED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3682,
  serialized_end=3763,
)
_sym_db.RegisterEnumDescriptor(_CONVOLUTIONALCODINGSTATUS)

ConvolutionalCodingStatus = enum_type_wrapper.EnumTypeWrapper(_CONVOLUTIONALCODINGSTATUS)
UNLOCKED = 0
I_LOCKED = 1
Q_LOCKED = 2
LOCKED = 3


_REEDSOLOMONSTATUS_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERLEAVE_ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CORRECTION_CAPACITY_EXCEEDED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2080,
  serialized_end=2152,
)
_sym_db.RegisterEnumDescriptor(_REEDSOLOMONSTATUS_STATUS)

_PLANLIFECYCLEEVENT_FAILUREDETAILS_CAUSE = _descriptor.EnumDescriptor(
  name='Cause',
  full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent.FailureDetails.Cause',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3479,
  serialized_end=3499,
)
_sym_db.RegisterEnumDescriptor(_PLANLIFECYCLEEVENT_FAILUREDETAILS_CAUSE)

_PLANLIFECYCLEEVENT_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREPARING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXECUTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3501,
  serialized_end=3579,
)
_sym_db.RegisterEnumDescriptor(_PLANLIFECYCLEEVENT_STATUS)


_TRANSMITTERCONFIGURATION = _descriptor.Descriptor(
  name='TransmitterConfiguration',
  full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.modulation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_carrier_enabled', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.is_carrier_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.bitrate', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.line_coding', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter_bandwidth_hz', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.filter_bandwidth_hz', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_frequency_hz', full_name='stellarstation.api.v1.monitoring.TransmitterConfiguration.sampling_frequency_hz', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=290,
  serialized_end=544,
)


_RECEIVERCONFIGURATION = _descriptor.Descriptor(
  name='ReceiverConfiguration',
  full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modulation', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.modulation', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bandwidth_hz', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.bandwidth_hz', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sampling_frequency_hz', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.sampling_frequency_hz', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.bitrate', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='line_coding', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.line_coding', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='synchronization_word', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.synchronization_word', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_convolutional_code_descrambling', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_convolutional_code_descrambling', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_convolutional_code_decoding', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_convolutional_code_decoding', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_convolutional_code_inverted', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_convolutional_code_inverted', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_reed_solomon_enabled', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_reed_solomon_enabled', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frame_size', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.frame_size', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_frame_checking_enabled', full_name='stellarstation.api.v1.monitoring.ReceiverConfiguration.is_frame_checking_enabled', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=547,
  serialized_end=1041,
)


_PLANCONFIGURATION = _descriptor.Descriptor(
  name='PlanConfiguration',
  full_name='stellarstation.api.v1.monitoring.PlanConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tle', full_name='stellarstation.api.v1.monitoring.PlanConfiguration.tle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1043,
  serialized_end=1109,
)


_GROUNDSTATIONCONFIGURATION = _descriptor.Descriptor(
  name='GroundStationConfiguration',
  full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration.transmitter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration.receiver', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='antenna', full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration.antenna', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.monitoring.GroundStationConfiguration.plan', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1112,
  serialized_end=1433,
)


_TRANSMITTERSTATE = _descriptor.Descriptor(
  name='TransmitterState',
  full_name='stellarstation.api.v1.monitoring.TransmitterState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='center_frequency_hz', full_name='stellarstation.api.v1.monitoring.TransmitterState.center_frequency_hz', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='carrier_level_dbm', full_name='stellarstation.api.v1.monitoring.TransmitterState.carrier_level_dbm', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_modulation_enabled', full_name='stellarstation.api.v1.monitoring.TransmitterState.is_modulation_enabled', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_carrier_enabled', full_name='stellarstation.api.v1.monitoring.TransmitterState.is_carrier_enabled', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_if_sweep_enabled', full_name='stellarstation.api.v1.monitoring.TransmitterState.is_if_sweep_enabled', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_idle_pattern_enabled', full_name='stellarstation.api.v1.monitoring.TransmitterState.is_idle_pattern_enabled', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.monitoring.TransmitterState.bitrate', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='carrier_offset', full_name='stellarstation.api.v1.monitoring.TransmitterState.carrier_offset', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1436,
  serialized_end=1842,
)


_REEDSOLOMONSTATUS = _descriptor.Descriptor(
  name='ReedSolomonStatus',
  full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_corrected_signals', full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.num_corrected_signals', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_good_frames', full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.num_good_frames', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_bad_frames', full_name='stellarstation.api.v1.monitoring.ReedSolomonStatus.num_bad_frames', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REEDSOLOMONSTATUS_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1845,
  serialized_end=2152,
)


_RECEIVERSTATE = _descriptor.Descriptor(
  name='ReceiverState',
  full_name='stellarstation.api.v1.monitoring.ReceiverState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='center_frequency_hz', full_name='stellarstation.api.v1.monitoring.ReceiverState.center_frequency_hz', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='carrier_level_dbm', full_name='stellarstation.api.v1.monitoring.ReceiverState.carrier_level_dbm', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_phase_locked', full_name='stellarstation.api.v1.monitoring.ReceiverState.is_phase_locked', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_bit_synchronizer_locked', full_name='stellarstation.api.v1.monitoring.ReceiverState.is_bit_synchronizer_locked', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='normalized_snr', full_name='stellarstation.api.v1.monitoring.ReceiverState.normalized_snr', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_frame_synchronizer_locked', full_name='stellarstation.api.v1.monitoring.ReceiverState.is_frame_synchronizer_locked', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convolutional_coding_status', full_name='stellarstation.api.v1.monitoring.ReceiverState.convolutional_coding_status', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='convolutional_coding_bit_error_rate', full_name='stellarstation.api.v1.monitoring.ReceiverState.convolutional_coding_bit_error_rate', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reed_solomon_status', full_name='stellarstation.api.v1.monitoring.ReceiverState.reed_solomon_status', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bitrate', full_name='stellarstation.api.v1.monitoring.ReceiverState.bitrate', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='carrier_offset', full_name='stellarstation.api.v1.monitoring.ReceiverState.carrier_offset', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2673,
)


_ANTENNASTATE_ANGLE = _descriptor.Descriptor(
  name='Angle',
  full_name='stellarstation.api.v1.monitoring.AntennaState.Angle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='stellarstation.api.v1.monitoring.AntennaState.Angle.command', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measured', full_name='stellarstation.api.v1.monitoring.AntennaState.Angle.measured', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2910,
  serialized_end=2952,
)

_ANTENNASTATE = _descriptor.Descriptor(
  name='AntennaState',
  full_name='stellarstation.api.v1.monitoring.AntennaState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='azimuth', full_name='stellarstation.api.v1.monitoring.AntennaState.azimuth', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='stellarstation.api.v1.monitoring.AntennaState.elevation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polarization', full_name='stellarstation.api.v1.monitoring.AntennaState.polarization', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ANTENNASTATE_ANGLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2676,
  serialized_end=2952,
)


_GROUNDSTATIONSTATE = _descriptor.Descriptor(
  name='GroundStationState',
  full_name='stellarstation.api.v1.monitoring.GroundStationState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transmitter', full_name='stellarstation.api.v1.monitoring.GroundStationState.transmitter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiver', full_name='stellarstation.api.v1.monitoring.GroundStationState.receiver', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='antenna', full_name='stellarstation.api.v1.monitoring.GroundStationState.antenna', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2955,
  serialized_end=3180,
)


_PLANLIFECYCLEEVENT_FAILUREDETAILS = _descriptor.Descriptor(
  name='FailureDetails',
  full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent.FailureDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cause', full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent.FailureDetails.cause', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PLANLIFECYCLEEVENT_FAILUREDETAILS_CAUSE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3371,
  serialized_end=3499,
)

_PLANLIFECYCLEEVENT = _descriptor.Descriptor(
  name='PlanLifecycleEvent',
  full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure', full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent.failure', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_PLANLIFECYCLEEVENT_FAILUREDETAILS, ],
  enum_types=[
    _PLANLIFECYCLEEVENT_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='Details', full_name='stellarstation.api.v1.monitoring.PlanLifecycleEvent.Details',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3183,
  serialized_end=3590,
)


_GROUNDSTATIONEVENT = _descriptor.Descriptor(
  name='GroundStationEvent',
  full_name='stellarstation.api.v1.monitoring.GroundStationEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='plan', full_name='stellarstation.api.v1.monitoring.GroundStationEvent.plan', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3592,
  serialized_end=3680,
)

_TRANSMITTERCONFIGURATION.fields_by_name['modulation'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._MODULATION
_TRANSMITTERCONFIGURATION.fields_by_name['line_coding'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._LINECODING
_RECEIVERCONFIGURATION.fields_by_name['modulation'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._MODULATION
_RECEIVERCONFIGURATION.fields_by_name['line_coding'].enum_type = stellarstation_dot_api_dot_v1_dot_radio_dot_radio__pb2._LINECODING
_RECEIVERCONFIGURATION.fields_by_name['synchronization_word'].message_type = stellarstation_dot_api_dot_v1_dot_common_dot_common__pb2._BITS
_PLANCONFIGURATION.fields_by_name['tle'].message_type = stellarstation_dot_api_dot_v1_dot_orbit_dot_orbit__pb2._TLE
_GROUNDSTATIONCONFIGURATION.fields_by_name['transmitter'].message_type = _TRANSMITTERCONFIGURATION
_GROUNDSTATIONCONFIGURATION.fields_by_name['receiver'].message_type = _RECEIVERCONFIGURATION
_GROUNDSTATIONCONFIGURATION.fields_by_name['antenna'].message_type = stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2._ANTENNACONFIGURATION
_GROUNDSTATIONCONFIGURATION.fields_by_name['plan'].message_type = _PLANCONFIGURATION
_TRANSMITTERSTATE.fields_by_name['is_modulation_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERSTATE.fields_by_name['is_carrier_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERSTATE.fields_by_name['is_if_sweep_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERSTATE.fields_by_name['is_idle_pattern_enabled'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_TRANSMITTERSTATE.fields_by_name['bitrate'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_TRANSMITTERSTATE.fields_by_name['carrier_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_REEDSOLOMONSTATUS.fields_by_name['status'].enum_type = _REEDSOLOMONSTATUS_STATUS
_REEDSOLOMONSTATUS.fields_by_name['num_good_frames'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REEDSOLOMONSTATUS.fields_by_name['num_bad_frames'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_REEDSOLOMONSTATUS_STATUS.containing_type = _REEDSOLOMONSTATUS
_RECEIVERSTATE.fields_by_name['convolutional_coding_status'].enum_type = _CONVOLUTIONALCODINGSTATUS
_RECEIVERSTATE.fields_by_name['reed_solomon_status'].message_type = _REEDSOLOMONSTATUS
_RECEIVERSTATE.fields_by_name['bitrate'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_RECEIVERSTATE.fields_by_name['carrier_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._FLOATVALUE
_ANTENNASTATE_ANGLE.containing_type = _ANTENNASTATE
_ANTENNASTATE.fields_by_name['azimuth'].message_type = _ANTENNASTATE_ANGLE
_ANTENNASTATE.fields_by_name['elevation'].message_type = _ANTENNASTATE_ANGLE
_ANTENNASTATE.fields_by_name['polarization'].enum_type = stellarstation_dot_api_dot_v1_dot_antenna_dot_antenna__pb2._ANTENNAPOLARIZATION
_GROUNDSTATIONSTATE.fields_by_name['transmitter'].message_type = _TRANSMITTERSTATE
_GROUNDSTATIONSTATE.fields_by_name['receiver'].message_type = _RECEIVERSTATE
_GROUNDSTATIONSTATE.fields_by_name['antenna'].message_type = _ANTENNASTATE
_PLANLIFECYCLEEVENT_FAILUREDETAILS.fields_by_name['cause'].enum_type = _PLANLIFECYCLEEVENT_FAILUREDETAILS_CAUSE
_PLANLIFECYCLEEVENT_FAILUREDETAILS.containing_type = _PLANLIFECYCLEEVENT
_PLANLIFECYCLEEVENT_FAILUREDETAILS_CAUSE.containing_type = _PLANLIFECYCLEEVENT_FAILUREDETAILS
_PLANLIFECYCLEEVENT.fields_by_name['status'].enum_type = _PLANLIFECYCLEEVENT_STATUS
_PLANLIFECYCLEEVENT.fields_by_name['failure'].message_type = _PLANLIFECYCLEEVENT_FAILUREDETAILS
_PLANLIFECYCLEEVENT_STATUS.containing_type = _PLANLIFECYCLEEVENT
_PLANLIFECYCLEEVENT.oneofs_by_name['Details'].fields.append(
  _PLANLIFECYCLEEVENT.fields_by_name['failure'])
_PLANLIFECYCLEEVENT.fields_by_name['failure'].containing_oneof = _PLANLIFECYCLEEVENT.oneofs_by_name['Details']
_GROUNDSTATIONEVENT.fields_by_name['plan'].message_type = _PLANLIFECYCLEEVENT
DESCRIPTOR.message_types_by_name['TransmitterConfiguration'] = _TRANSMITTERCONFIGURATION
DESCRIPTOR.message_types_by_name['ReceiverConfiguration'] = _RECEIVERCONFIGURATION
DESCRIPTOR.message_types_by_name['PlanConfiguration'] = _PLANCONFIGURATION
DESCRIPTOR.message_types_by_name['GroundStationConfiguration'] = _GROUNDSTATIONCONFIGURATION
DESCRIPTOR.message_types_by_name['TransmitterState'] = _TRANSMITTERSTATE
DESCRIPTOR.message_types_by_name['ReedSolomonStatus'] = _REEDSOLOMONSTATUS
DESCRIPTOR.message_types_by_name['ReceiverState'] = _RECEIVERSTATE
DESCRIPTOR.message_types_by_name['AntennaState'] = _ANTENNASTATE
DESCRIPTOR.message_types_by_name['GroundStationState'] = _GROUNDSTATIONSTATE
DESCRIPTOR.message_types_by_name['PlanLifecycleEvent'] = _PLANLIFECYCLEEVENT
DESCRIPTOR.message_types_by_name['GroundStationEvent'] = _GROUNDSTATIONEVENT
DESCRIPTOR.enum_types_by_name['ConvolutionalCodingStatus'] = _CONVOLUTIONALCODINGSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransmitterConfiguration = _reflection.GeneratedProtocolMessageType('TransmitterConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMITTERCONFIGURATION,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.TransmitterConfiguration)
  })
_sym_db.RegisterMessage(TransmitterConfiguration)

ReceiverConfiguration = _reflection.GeneratedProtocolMessageType('ReceiverConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVERCONFIGURATION,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.ReceiverConfiguration)
  })
_sym_db.RegisterMessage(ReceiverConfiguration)

PlanConfiguration = _reflection.GeneratedProtocolMessageType('PlanConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _PLANCONFIGURATION,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.PlanConfiguration)
  })
_sym_db.RegisterMessage(PlanConfiguration)

GroundStationConfiguration = _reflection.GeneratedProtocolMessageType('GroundStationConfiguration', (_message.Message,), {
  'DESCRIPTOR' : _GROUNDSTATIONCONFIGURATION,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.GroundStationConfiguration)
  })
_sym_db.RegisterMessage(GroundStationConfiguration)

TransmitterState = _reflection.GeneratedProtocolMessageType('TransmitterState', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMITTERSTATE,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.TransmitterState)
  })
_sym_db.RegisterMessage(TransmitterState)

ReedSolomonStatus = _reflection.GeneratedProtocolMessageType('ReedSolomonStatus', (_message.Message,), {
  'DESCRIPTOR' : _REEDSOLOMONSTATUS,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.ReedSolomonStatus)
  })
_sym_db.RegisterMessage(ReedSolomonStatus)

ReceiverState = _reflection.GeneratedProtocolMessageType('ReceiverState', (_message.Message,), {
  'DESCRIPTOR' : _RECEIVERSTATE,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.ReceiverState)
  })
_sym_db.RegisterMessage(ReceiverState)

AntennaState = _reflection.GeneratedProtocolMessageType('AntennaState', (_message.Message,), {

  'Angle' : _reflection.GeneratedProtocolMessageType('Angle', (_message.Message,), {
    'DESCRIPTOR' : _ANTENNASTATE_ANGLE,
    '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.AntennaState.Angle)
    })
  ,
  'DESCRIPTOR' : _ANTENNASTATE,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.AntennaState)
  })
_sym_db.RegisterMessage(AntennaState)
_sym_db.RegisterMessage(AntennaState.Angle)

GroundStationState = _reflection.GeneratedProtocolMessageType('GroundStationState', (_message.Message,), {
  'DESCRIPTOR' : _GROUNDSTATIONSTATE,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.GroundStationState)
  })
_sym_db.RegisterMessage(GroundStationState)

PlanLifecycleEvent = _reflection.GeneratedProtocolMessageType('PlanLifecycleEvent', (_message.Message,), {

  'FailureDetails' : _reflection.GeneratedProtocolMessageType('FailureDetails', (_message.Message,), {
    'DESCRIPTOR' : _PLANLIFECYCLEEVENT_FAILUREDETAILS,
    '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
    # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.PlanLifecycleEvent.FailureDetails)
    })
  ,
  'DESCRIPTOR' : _PLANLIFECYCLEEVENT,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.PlanLifecycleEvent)
  })
_sym_db.RegisterMessage(PlanLifecycleEvent)
_sym_db.RegisterMessage(PlanLifecycleEvent.FailureDetails)

GroundStationEvent = _reflection.GeneratedProtocolMessageType('GroundStationEvent', (_message.Message,), {
  'DESCRIPTOR' : _GROUNDSTATIONEVENT,
  '__module__' : 'stellarstation.api.v1.monitoring.monitoring_pb2'
  # @@protoc_insertion_point(class_scope:stellarstation.api.v1.monitoring.GroundStationEvent)
  })
_sym_db.RegisterMessage(GroundStationEvent)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
